lyricstools.LyricExtender
=========================

.. inheritance-diagram:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender
   :private-bases:

.. autoclass:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.duration_in_seconds

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.format

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.leaf_index

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.multiplied_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.preprolated_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.duration_multiplier

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.written_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.written_pitch_indication_is_at_sounding_pitch

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.written_pitch_indication_is_nonsemantic

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

Special Methods
---------------

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__and__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__or__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__repr__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__str__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__sub__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricExtender.LyricExtender.LyricExtender.__xor__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`
